@@ -8,6 +8,14 @@ else:
 
 LEAGUE_ID = "00"
 
+class StatusCode:
+    def __init__(self):
+        self.status_code = {
+            "OK": 200,
+            "NotExist": 404,
+            "InternalError": 500
+        }
+
 class EndPoints:
     def __init__(self):
         self.endpoints = {
